@@ -30,6 +30,11 @@ define('NAG_SORT_CATEGORY', 'category');
  */
 define('NAG_SORT_OWNER', 'tasklist');
 
+/**
+ * Sort by estimate.
+ */
+define('NAG_SORT_ESTIMATE', 'estimate');
+
 /**
  * Sort by assignee.
  */
@@ -48,7 +53,7 @@ define('NAG_SORT_DESCEND', 1);
 /**
  * Nag Base Class.
  *
- * $Horde: nag/lib/Nag.php,v 1.124.2.29 2008/07/28 10:59:30 jan Exp $
+ * $Horde: nag/lib/Nag.php,v 1.124.2.34 2009/06/19 17:20:13 jan Exp $
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -95,9 +100,7 @@ class Nag {
      *
      * This function will also sort the resulting list, if requested.
      *
-     * @param string $sortby      The field by which to sort
-     *                            (NAG_SORT_PRIORITY, NAG_SORT_NAME
-     *                            NAG_SORT_DUE, NAG_SORT_COMPLETION).
+     * @param string $sortby      The field by which to sort (NAG_SORT_*).
      * @param integer $sortdir    The direction by which to sort
      *                            (NAG_SORT_ASCEND, NAG_SORT_DESCEND).
      * @param string $altsortby   The secondary sort field.
@@ -162,12 +165,17 @@ class Nag {
                 if ($app != 'nag' &&
                     $registry->hasMethod('getListTypes', $app)) {
                     $types = $registry->callByPackage($app, 'getListTypes');
+                    if (is_a($types, 'PEAR_Error')) {
+                        continue;
+                    }
                     if (!empty($types['taskHash'])) {
                         $newtasks = $registry->callByPackage($app, 'listAs', array('taskHash'));
                         if (is_a($newtasks, 'PEAR_Error')) {
                             Horde::logMessage($newtasks, __FILE__, __LINE__, PEAR_LOG_ERR);
                         } else {
                             foreach ($newtasks as $task) {
+                                $task['tasklist_id'] = '**EXTERNAL**';
+                                $task['tasklist_name'] = $registry->get('name', $app);
                                 $tasks->add(new Nag_Task($task));
                             }
                         }
@@ -276,7 +284,13 @@ class Nag {
      */
     function listTasklists($owneronly = false, $permission = PERMS_SHOW)
     {
-        $tasklists = $GLOBALS['nag_shares']->listShares(Auth::getAuth(), $permission, $owneronly ? Auth::getAuth() : null, 0, 0, 'name');
+        // Work around BC break in listShares() parameters (http://bugs.horde.org/ticket/7820)
+        include_once $GLOBALS['registry']->get('fileroot', 'horde') . '/lib/version.php';
+        if (version_compare(HORDE_VERSION, '3.2', '<')) {
+            $tasklists = $GLOBALS['nag_shares']->listShares(Auth::getAuth(), $permission, $owneronly ? Auth::getAuth() : null, DATATREE_ROOT, true, 0, 0, 'name');
+        } else {
+            $tasklists = $GLOBALS['nag_shares']->listShares(Auth::getAuth(), $permission, $owneronly ? Auth::getAuth() : null, 0, 0, 'name');
+        }
         if (is_a($tasklists, 'PEAR_Error')) {
             Horde::logMessage($tasklists, __FILE__, __LINE__, PEAR_LOG_ERR);
             return array();
@@ -783,7 +797,7 @@ class Nag {
                     . "\n\n"
                     . _("The task \"%s\" has been added to task list \"%s\", with a due date of: %s.")
                     . "\n"
-                    . $view_link;
+                    . str_replace("%","%%",$view_link);
                 break;
 
             case 'edit':
@@ -792,7 +806,7 @@ class Nag {
                     . "\n\n"
                     . _("The task \"%s\" has been edited on task list \"%s\".")
                     . "\n"
-                    . $view_link
+                    . str_replace("%","%%",$view_link)
                     . "\n\n"
                     . _("Changes made for this task:");
                 if ($old_task->name != $task->name) {
@@ -1057,6 +1071,72 @@ class Nag {
         return strcasecmp($b->name, $a->name);
     }
 
+    /**
+     * Comparison function for sorting tasks by assignee.
+     *
+     * @param array $a  Task one.
+     * @param array $b  Task two.
+     *
+     * @return integer  1 if task one is greater, -1 if task two is greater;
+     *                  0 if they are equal.
+     */
+    function _sortByAssignee($a, $b)
+    {
+        return strcasecmp($a->assignee, $b->assignee);
+    }
+
+    /**
+     * Comparison function for reverse sorting tasks by assignee.
+     *
+     * @param array $a  Task one.
+     * @param array $b  Task two.
+     *
+     * @return integer  -1 if task one is greater, 1 if task two is greater;
+     *                  0 if they are equal.
+     */
+    function _rsortByAssignee($a, $b)
+    {
+        return strcasecmp($b->assignee, $a->assignee);
+    }
+
+    /**
+     * Comparison function for sorting tasks by assignee.
+     *
+     * @param array $a  Task one.
+     * @param array $b  Task two.
+     *
+     * @return integer  1 if task one is greater, -1 if task two is greater;
+     *                  0 if they are equal.
+     */
+    function _sortByEstimate($a, $b)
+    {
+        $a_est = $a->estimation();
+        $b_est = $b->estimation();
+        if ($a_est == $b_est) {
+            return 0;
+        }
+        return ($a_est > $b_est) ? 1 : -1;
+    }
+
+    /**
+     * Comparison function for reverse sorting tasks by name.
+     *
+     * @param array $a  Task one.
+     * @param array $b  Task two.
+     *
+     * @return integer  -1 if task one is greater, 1 if task two is greater;
+     *                  0 if they are equal.
+     */
+    function _rsortByEstimate($a, $b)
+    {
+        $a_est = $a->estimation();
+        $b_est = $b->estimation();
+        if ($a_est == $b_est) {
+            return 0;
+        }
+        return ($a_est > $b_est) ? -1 : 1;
+    }
+
     /**
      * Comparison function for sorting tasks by category.
      *
